aboutsummaryrefslogtreecommitdiffstats
path: root/nclients.scm
diff options
context:
space:
mode:
Diffstat (limited to 'nclients.scm')
-rw-r--r--nclients.scm20
1 files changed, 10 insertions, 10 deletions
diff --git a/nclients.scm b/nclients.scm
index 530683d..08f3d0b 100644
--- a/nclients.scm
+++ b/nclients.scm
@@ -1,9 +1,9 @@
;;; "nclients.scm" Interface to net-client programs.
; Copyright 1997, 1998 Aubrey Jaffer
;
-;Permission to copy this software, to redistribute it, and to use it
-;for any purpose is granted, subject to the following restrictions and
-;understandings.
+;Permission to copy this software, to modify it, to redistribute it,
+;to distribute modified versions, and to use it for any purpose is
+;granted, subject to the following restrictions and understandings.
;
;1. Any copy made of this software must include this copyright notice
;in full.
@@ -226,11 +226,11 @@
;;@item
;;remote-directory
;;@end enumerate
-(define (parse-ftp-address url)
+(define (parse-ftp-address uri)
(define length? (lambda (len lst) (and (eqv? len (length lst)) lst)))
(cond
- ((not url) #f)
- ((length? 1 (scanf-read-list " ftp://%s %s" url))
+ ((not uri) #f)
+ ((length? 1 (scanf-read-list " ftp://%s %s" uri))
=> (lambda (host)
(let ((login #f) (path #f) (dross #f))
(sscanf (car host) "%[^/]/%[^@]%s" login path dross)
@@ -248,7 +248,7 @@
(list path))))))
(else
(let ((user@site #f) (colon #f) (path #f) (dross #f))
- (case (sscanf url " %[^:]%[:]%[^@] %s" user@site colon path dross)
+ (case (sscanf uri " %[^:]%[:]%[^@] %s" user@site colon path dross)
((2 3)
(let ((user #f) (site #f))
(cond ((or (eqv? 2 (sscanf user@site "/%[^@/]@%[^@]%s"
@@ -260,7 +260,7 @@
(list #f #f site path))
(else (list #f #f user@site path)))))
(else
- (let ((site (scanf-read-list " %[^@/] %s" url)))
+ (let ((site (scanf-read-list " %[^@/] %s" uri)))
(and (length? 1 site) (list #f #f (car site) #f)))))))))
;;@body
@@ -364,8 +364,8 @@
2))
;;@body
-;;Returns a URL-string for @1 on the local host.
-(define (path->url path)
+;;Returns a URI-string for @1 on the local host.
+(define (path->uri path)
(if (absolute-path? path)
(sprintf #f "file:%s" path)
(sprintf #f "file:%s/%s" (current-directory) path)))